@@ -34,6 +34,7 @@
 
 #include <algorithm>
 #include <deque>
+#include <limits>
 #include <map>
 #include <numeric>
 #include <set>
@@ -64,7 +65,7 @@ public:
 
 private:
     // MEMBERS
-    vluint32_t m_mtaskId;  // MTask that did enqueue
+    uint32_t m_mtaskId;  // MTask that did enqueue
     std::function<void()> m_cb;  // Lambda to execute when message received
 public:
     // CONSTRUCTORS
@@ -77,7 +78,7 @@ public:
     VerilatedMsg& operator=(const VerilatedMsg&) = default;
     VerilatedMsg& operator=(VerilatedMsg&&) = default;
     // METHODS
-    vluint32_t mtaskId() const { return m_mtaskId; }
+    uint32_t mtaskId() const { return m_mtaskId; }
     // Execute the lambda function
     void run() const { m_cb(); }
 };
@@ -88,7 +89,7 @@ public:
 class VerilatedEvalMsgQueue final {
     using VerilatedThreadQueue = std::multiset<VerilatedMsg, VerilatedMsg::Cmp>;
 
-    std::atomic<vluint64_t> m_depth;  // Current depth of queue (see comments below)
+    std::atomic<uint64_t> m_depth;  // Current depth of queue (see comments below)
 
     VerilatedMutex m_mutex;  // Mutex protecting queue
     VerilatedThreadQueue m_queue VL_GUARDED_BY(m_mutex);  // Message queue
@@ -244,8 +245,8 @@ public:  // But only for verilated*.cpp
     // METHODS - extending into VerilatedContext, call via impp()->
 
     // Random seed handling
-    vluint64_t randSeedDefault64() const VL_MT_SAFE;
-    static vluint32_t randSeedEpoch() VL_MT_SAFE { return s().s_randSeedEpoch; }
+    uint64_t randSeedDefault64() const VL_MT_SAFE;
+    static uint32_t randSeedEpoch() VL_MT_SAFE { return s().s_randSeedEpoch; }
 
     // METHODS - timeformat
     int timeFormatUnits() const VL_MT_SAFE {
@@ -394,7 +395,11 @@ protected:
     // METHODS - protected
     void commandArgsAddGuts(int argc, const char** argv);
     void commandArgVl(const std::string& arg);
-    bool commandArgVlValue(const std::string& arg, const std::string& prefix, std::string& valuer);
+    bool commandArgVlString(const std::string& arg, const std::string& prefix,
+                            std::string& valuer);
+    bool commandArgVlUint64(const std::string& arg, const std::string& prefix, uint64_t& valuer,
+                            uint64_t min = std::numeric_limits<uint64_t>::min(),
+                            uint64_t max = std::numeric_limits<uint64_t>::max());
     void commandArgDump() const VL_MT_SAFE_EXCLUDES(m_argMutex);
 };
 
@@ -484,7 +489,7 @@ public:
 public:  // But only for verilated.cpp
     // Symbol table destruction cleans up the entries for each scope.
     static void userEraseScope(const VerilatedScope* scopep) VL_MT_SAFE {
-        // Slow ok - called once/scope on destruction, so we simply iterate.
+        // Slow ok - called once/scope on destruction, so we only iterate.
         const VerilatedLockGuard lock{s().m_userMapMutex};
         for (auto it = s().m_userMap.begin(); it != s().m_userMap.end();) {
             if (it->first.first == scopep) {
